@@ -23,11 +23,12 @@ import (
 )
 
 var (
-	reHTTPURL  = regexp.MustCompile(`Possibly bad HTTP URL: [^ ]+ . ([^ ]+) . ([^" ]+)`)
-	reHTTPHost = regexp.MustCompile(`Possibly bad HTTP host: ([^" ]+)`)
-	reDNSReq   = regexp.MustCompile("Possibly bad DNS lookup to ([^\" ]+)")
-	reDNSRep   = regexp.MustCompile("Possibly bad DNS response for ([^\" ]+)")
-	reSNI      = regexp.MustCompile("Possibly bad TLS SNI: ([^\" ]+)")
+	reHTTPURL     = regexp.MustCompile(`Possibly bad HTTP URL: [^ ]+ . ([^ ]+) . ([^" ]+)`)
+	reHTTPHost    = regexp.MustCompile(`Possibly bad HTTP host: ([^" ]+)`)
+	reDNSReq      = regexp.MustCompile("Possibly bad DNS lookup to ([^\" ]+)")
+	reDNSRep      = regexp.MustCompile("Possibly bad DNS response for ([^\" ]+)")
+	reSNI         = regexp.MustCompile("Possibly bad TLS SNI: ([^\" ]+)")
+	reFingerprint = regexp.MustCompile("Possibly bad TLS Fingerprint: ([^\" ]+)")
 )
 
 func makeBloomDNSEvent(rrname string) types.Entry {
@@ -109,16 +110,17 @@ func makeBloomHTTPEvent(host string, url string) types.Entry {
 	return e
 }
 
-func makeBloomTLSEvent(host string) types.Entry {
+func makeBloomTLSEvent(host string, fingerprint string) types.Entry {
 	e := types.Entry{
-		SrcIP:     fmt.Sprintf("10.0.0.%d", rand.Intn(5)+1),
-		SrcPort:   int64(rand.Intn(60000) + 1025),
-		DestIP:    fmt.Sprintf("10.0.0.%d", rand.Intn(50)),
-		DestPort:  443,
-		Timestamp: time.Now().Format(types.SuricataTimestampFormat),
-		EventType: "tls",
-		Proto:     "TCP",
-		TLSSNI:    host,
+		SrcIP:          fmt.Sprintf("10.0.0.%d", rand.Intn(5)+1),
+		SrcPort:        int64(rand.Intn(60000) + 1025),
+		DestIP:         fmt.Sprintf("10.0.0.%d", rand.Intn(50)),
+		DestPort:       443,
+		Timestamp:      time.Now().Format(types.SuricataTimestampFormat),
+		EventType:      "tls",
+		Proto:          "TCP",
+		TLSSNI:         host,
+		TLSFingerprint: fingerprint,
 	}
 	eve := types.EveEvent{
 		Timestamp: &types.SuriTime{
@@ -131,7 +133,8 @@ func makeBloomTLSEvent(host string) types.Entry {
 		DestPort:  int(e.DestPort),
 		Proto:     e.Proto,
 		TLS: &types.TLSEvent{
-			Sni: e.TLSSNI,
+			Sni:         e.TLSSNI,
+			Fingerprint: e.TLSFingerprint,
 		},
 	}
 	json, err := json.Marshal(eve)
@@ -146,6 +149,7 @@ func makeBloomTLSEvent(host string) types.Entry {
 var testURLs []string
 var testHosts []string
 var testTLSHosts []string
+var testTLSFingerprints []string
 
 const numOfTestBloomItems = 1000
 
@@ -156,9 +160,9 @@ func fillBloom(b *bloom.BloomFilter) {
 	testTLSHosts = make([]string, 0)
 	i := 0
 	for i < numOfTestBloomItems {
-		val := fmt.Sprintf("%s.com", util.RandStringBytesMaskImprSrc(6))
+		val := fmt.Sprintf("%s.com", util.RndStringFromAlpha(6))
 		for b.Check([]byte(val)) {
-			val = fmt.Sprintf("%s.com", util.RandStringBytesMaskImprSrc(6))
+			val = fmt.Sprintf("%s.com", util.RndStringFromAlpha(6))
 		}
 		i++
 		testHosts = append(testHosts, val)
@@ -166,9 +170,9 @@ func fillBloom(b *bloom.BloomFilter) {
 	}
 	i = 0
 	for i < numOfTestBloomItems {
-		val := fmt.Sprintf("%s.com", util.RandStringBytesMaskImprSrc(6))
+		val := fmt.Sprintf("%s.com", util.RndStringFromAlpha(6))
 		for b.Check([]byte(val)) {
-			val = fmt.Sprintf("%s.com", util.RandStringBytesMaskImprSrc(6))
+			val = fmt.Sprintf("%s.com", util.RndStringFromAlpha(6))
 		}
 		i++
 		testTLSHosts = append(testTLSHosts, val)
@@ -176,14 +180,21 @@ func fillBloom(b *bloom.BloomFilter) {
 	}
 	i = 0
 	for i < numOfTestBloomItems {
-		val := fmt.Sprintf("http://foo.com/%s.html", util.RandStringBytesMaskImprSrc(6))
+		val := fmt.Sprintf("http://foo.com/%s.html", util.RndStringFromAlpha(6))
 		for b.Check([]byte(val)) {
-			val = fmt.Sprintf("http://foo.com/%s.html", util.RandStringBytesMaskImprSrc(6))
+			val = fmt.Sprintf("http://foo.com/%s.html", util.RndStringFromAlpha(6))
 		}
 		i++
 		testURLs = append(testURLs, val)
 		b.Add([]byte(val))
 	}
+	i = 0
+	for i < numOfTestBloomItems {
+		i++
+		fingp := util.RndTLSFingerprint()
+		testTLSFingerprints = append(testTLSFingerprints, fingp)
+		b.Add([]byte(fingp))
+	}
 }
 
 // CollectorHandler simply gathers consumed events in a list
@@ -246,6 +257,11 @@ func (h *CollectorHandler) Consume(e *types.Entry) error {
 		h.Entries[match[1]] = true
 		return nil
 	}
+	match = reFingerprint.FindStringSubmatch(e.JSONLine)
+	if match != nil {
+		h.Entries[match[1]] = true
+		return nil
+	}
 	return nil
 }
 
@@ -262,9 +278,6 @@ func (h *CollectorHandler) GetEntries() map[string]bool {
 }
 
 func TestBloomHandler(t *testing.T) {
-	// make sure that alerts are forwarded
-	util.PrepareEventFilter([]string{"alert"}, false)
-
 	// initalize Bloom filter and fill with 'interesting' values
 	bf := bloom.Initialize(100000, 0.0000001)
 	fillBloom(&bf)
@@ -314,6 +327,7 @@ func TestBloomHandler(t *testing.T) {
 	i := 0
 	j := 0
 	k := 0
+	l := 0
 	for {
 		var e types.Entry
 		// emit Bloom filter TP event with 20% individual probability, at most
@@ -323,7 +337,7 @@ func TestBloomHandler(t *testing.T) {
 				break
 			}
 			// uniformly distribute hits over HTTP URL/Host and DNS lookups
-			switch rnd := rand.Intn(3); rnd {
+			switch rnd := rand.Intn(4); rnd {
 			case 0:
 				if i < numOfTestBloomItems {
 					e = makeBloomDNSEvent(testHosts[i])
@@ -338,37 +352,50 @@ func TestBloomHandler(t *testing.T) {
 				}
 			case 2:
 				if k < numOfTestBloomItems {
-					e = makeBloomTLSEvent(testTLSHosts[k])
+					e = makeBloomTLSEvent(testTLSHosts[k], ":::")
 					bh.Consume(&e)
 					k++
 				}
+			case 3:
+				if l < numOfTestBloomItems {
+					e = makeBloomTLSEvent("foo.com", testTLSFingerprints[l])
+					bh.Consume(&e)
+					l++
+				}
 			}
 		} else {
 			// uniformly distribute non-matching hits over HTTP URL/Host and DNS lookups
-			switch rnd := rand.Intn(3); rnd {
+			switch rnd := rand.Intn(4); rnd {
 			case 0:
-				s := fmt.Sprintf("%s.com", util.RandStringBytesMaskImprSrc(6))
+				s := fmt.Sprintf("%s.com", util.RndStringFromAlpha(6))
 				for bf.Check([]byte(s)) {
-					s = fmt.Sprintf("%s.%s", util.RandStringBytesMaskImprSrc(6),
-						util.RandStringBytesMaskImprSrc(2))
+					s = fmt.Sprintf("%s.%s", util.RndStringFromAlpha(6),
+						util.RndStringFromAlpha(2))
 				}
 				e = makeBloomDNSEvent(s)
 				bh.Consume(&e)
 			case 1:
-				s := fmt.Sprintf("/%s.html", util.RandStringBytesMaskImprSrc(6))
+				s := fmt.Sprintf("/%s.html", util.RndStringFromAlpha(6))
 				for bf.Check([]byte(s)) {
-					s = fmt.Sprintf("/%s.%s.html", util.RandStringBytesMaskImprSrc(6),
-						util.RandStringBytesMaskImprSrc(6))
+					s = fmt.Sprintf("/%s.%s.html", util.RndStringFromAlpha(6),
+						util.RndStringFromAlpha(6))
 				}
 				e = makeBloomHTTPEvent("foo.com", s)
 				bh.Consume(&e)
 			case 2:
-				s := fmt.Sprintf("%s.com", util.RandStringBytesMaskImprSrc(6))
+				s := fmt.Sprintf("%s.com", util.RndStringFromAlpha(6))
 				for bf.Check([]byte(s)) {
-					s = fmt.Sprintf("%s.%s", util.RandStringBytesMaskImprSrc(6),
-						util.RandStringBytesMaskImprSrc(2))
+					s = fmt.Sprintf("%s.%s", util.RndStringFromAlpha(6),
+						util.RndStringFromAlpha(2))
 				}
-				e = makeBloomTLSEvent(s)
+				e = makeBloomTLSEvent(s, ":::")
+				bh.Consume(&e)
+			case 3:
+				f := util.RndStringFromAlpha(6)
+				for bf.Check([]byte(f)) {
+					f = util.RndStringFromAlpha(6)
+				}
+				e = makeBloomTLSEvent("foo.com", f)
 				bh.Consume(&e)
 			}
 		}
@@ -379,7 +406,7 @@ func TestBloomHandler(t *testing.T) {
 	<-consumeWaitChan
 
 	// check that we haven't missed anything
-	if len(fwhandler.Entries) < 3*numOfTestBloomItems {
+	if len(fwhandler.Entries) < 4*numOfTestBloomItems {
 		t.Fatalf("expected %d forwarded BLF alerts, seen less (%d)", numOfTestBloomItems,
 			len(fwhandler.Entries))
 	}
@@ -665,8 +692,6 @@ func TestBloomHandlerURL(t *testing.T) {
 		close(consumeWaitChan)
 	}()
 
-	util.PrepareEventFilter([]string{"alert"}, false)
-
 	// initalize Bloom filter and fill with 'interesting' values
 	bf := bloom.Initialize(100000, 0.0000001)
 	bf.Add([]byte("/oddlyspecific"))
@@ -920,8 +945,6 @@ func TestBloomHandlerBlacklistedSkip(t *testing.T) {
 		close(consumeWaitChan)
 	}()
 
-	util.PrepareEventFilter([]string{"alert"}, false)
-
 	// handler to receive forwarded events
 	fwhandler := &CollectorHandler{
 		Entries: make(map[string]bool),
@@ -951,9 +974,6 @@ func TestBloomHandlerBlacklistedSkip(t *testing.T) {
 }
 
 func TestBloomHandlerInvalidDNS(t *testing.T) {
-	// make sure that alerts are forwarded
-	util.PrepareEventFilter([]string{"alert"}, false)
-
 	// initalize Bloom filter and fill with 'interesting' values
 	bf := bloom.Initialize(100000, 0.0000001)
 
